Retrieve pagination metadata
Value
A list containing the resource, totals reported by the API, and
retrieved pages; NULL for other objects.
Examples
result_metadata(tibble::tibble())
#> NULL
Retrieve pagination metadata
A list containing the resource, totals reported by the API, and
retrieved pages; NULL for other objects.
result_metadata(tibble::tibble())
#> NULL