| list_filters | R Documentation |
Lists the filters published in the OpenAPI contract supported by this package. Unknown filters are rejected before a request is sent to prevent silently incorrect queries. Filter names and categorical values remain in Portuguese because they are part of the upstream API contract.
list_filters(resource)
obrasgov_filtros(recurso)
resource |
A resource name returned by |
recurso |
Portuguese alias for |
A tibble containing filter names, expected types, and allowed values when applicable.
list_filters("projects")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.